# jupyter-flex: Easy interactive dashboards for Jupyter

[![PyPI version](https://badge.fury.io/py/jupyter-flex.svg)](https://pypi.org/project/jupyter-flex/)
[![Docs](https://api.netlify.com/api/v1/badges/cba69018-b4a3-4015-9b9c-7f936304afa2/deploy-status)](https://jupyter-flex.netlify.com/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/danielfrg/jupyter-flex/master)

Use Jupyter Notebooks to quickly create interactive dashboards.

- Use [nbconvert](https://nbconvert.readthedocs.io/en/latest/) to create static reports
- Use [Voila](https://github.com/voila-dashboards/voila) to start a live Jupyter Kernel for fully dynamic applications
- Support for [ipywidgets](https://ipywidgets.readthedocs.io/en/latest/)
- Flexible and easy way to specify row and column based layouts
- Use Markdown headers and Jupyter Notebook cell tags to define the dashboard components

Inspired by [Flex Dashboards](https://rmarkdown.rstudio.com/flexdashboard/).

<a href="https://jupyter-flex.netlify.com/examples/nba-scoring.html"><img src="https://jupyter-flex.netlify.com/assets/img/nba-scoring.png" alt="Jupyter-flex: NBA Scoring" width=276></a>
<a href="https://jupyter-flex.netlify.com/examples/time-series.html"><img src="https://jupyter-flex.netlify.com/assets/img/time-series.png" alt="Jupyter-flex: Time Series"  width=276></a>
<a href="https://jupyter-flex.netlify.com/examples/iris-plots.html"><img src="https://jupyter-flex.netlify.com/assets/img/iris-plots.png" alt="Jupyter-flex: Iris Plots"  width=276></a>

## Installation

```
pip install jupyter-flex
```

## Learning More

Learn more in the [Jupyter-flex documentation](https://jupyter-flex.netlify.com/).
